__all__ = ['Banshee',
           'ddu',
           'Eclipse',
           'ekiga',
           'empathy',
           'evince',
           'evolution',
           'gajim',
           'gcalctool',
           'gdmlogin',
           'gedit',
           'gnome-documents',
           'gnome-keyring-ask',
           'gnome-mud',
           'gnome-panel',
           'gnome-screensaver-dialog',
           'gnome-search-tool',
           'gnome_segv2',
           'gnome-system-monitor',
           'gnome-terminal',
           'gnome-window-properties',
           'gtk-window-decorator',
           'Instantbird',
           'liferea',
           'metacity',
           'Mozilla',
           'nautilus',
           'notification-daemon',
           'notify-osd',
           'packagemanager',
           'pidgin',
           'planner',
           'rhythmbox',
           'soffice',
           'Thunderbird',
           'xfwm4']
